@@ -73,7 +73,8 @@
 # ../kid3/build.sh package
 
 # Exit if an error occurs
-set -e
+set -eE
+trap 'echo "Error on line $LINENO: $BASH_COMMAND"' ERR
 shopt -s extglob
 
 thisdir=$(pwd)
@@ -84,22 +85,22 @@ test ${kernel:0:5} = "MINGW" && kernel="MINGW"
 
 qt_version=6.5.3
 zlib_version=1.2.13
-zlib_patchlevel=3
+zlib_patchlevel=1
 libogg_version=1.3.4
 libogg_patchlevel=0.1
 libvorbis_version=1.3.7
-libvorbis_patchlevel=1
+libvorbis_patchlevel=2
 ffmpeg3_version=3.2.14
 ffmpeg3_patchlevel=1~deb9u1
-ffmpeg_version=5.1.4
+ffmpeg_version=5.1.6
 ffmpeg_patchlevel=0+deb12u1
 libflac_version=1.4.3+ds
-libflac_patchlevel=2
+libflac_patchlevel=2.1
 id3lib_version=3.8.3
 id3lib_patchlevel=18
-taglib_version=2.0
+taglib_version=2.0.2
 chromaprint_version=1.5.1
-chromaprint_patchlevel=4
+chromaprint_patchlevel=6
 mp4v2_version=2.1.3
 utfcpp_version=4.0.5
 
@@ -118,6 +119,20 @@ verify_in_srcdir() {
   fi
 }
 
+# The environment variable KID3_HOMEBREW_PKGS can be set to install packages
+# needed to build using Homebrew, if brew is not yet available a local instance
+# is installed.
+# Example: KID3_HOMEBREW_PKGS="cmake ninja autoconf automake libtool xz nasm docbook-xsl p7zip"
+if test -n "$KID3_HOMEBREW_PKGS"; then
+  export HOMEBREW_NO_INSTALL_UPGRADE=1
+  if ! brew install $KID3_HOMEBREW_PKGS; then
+    mkdir -p tools/Homebrew
+    curl -L https://github.com/Homebrew/brew/tarball/master | tar xz --strip 1 -C tools/Homebrew
+    eval "$(tools/Homebrew/bin/brew shellenv)"
+    brew install $KID3_HOMEBREW_PKGS
+  fi
+fi
+
 # Administrative subtasks
 
 # Changes version and date strings in all known Kid3 files.
@@ -261,10 +276,9 @@ set -e
    OSXPREFIX=/opt/osxcross/target \
    QTBINARYDIR=$HOME/Development/Qt6.5.3-linux/6.5.3/gcc_64/bin \
    ../kid3/build.sh && \
-   fatdmg=(kid3/*-Darwin.dmg) && \
-   slimdmg=${fatdmg/-Darwin./-Darwin-amd64.} && \
-   PATH=$PATH:/opt/osxcross/target/bin \
-   ../kid3/macosx/mac-strip-arm64.sh $fatdmg $slimdmg)
+   origdmg=(kid3/*-Darwin.dmg) && \
+   qt6dmg=${origdmg/-Darwin./-Darwin-amd64.} && \
+   mv $origdmg $qt6dmg)
 (cd macos_qt5_build && \
    rm -f kid3/*-Darwin.dmg && \
    COMPILER=cross-macos \
@@ -283,6 +297,15 @@ set -e
    ANDROID_SDK_ROOT=$HOME/Development/android-sdk \
    ANDROID_NDK_ROOT=$ANDROID_SDK_ROOT/ndk/23.1.7779620 \
    ../kid3/build.sh)
+(cd android_arm64_build && \
+   PATH=/opt/cmake/bin:$PATH \
+   COMPILER=cross-android \
+   QTPREFIX=$HOME/Development/Development/Qt6.5.3-android64/6.5.3/android_arm64_v8a \
+   QTBINARYDIR=$HOME/Development/Qt6.5.3-linux/6.5.3/gcc_64/bin \
+   JAVA_HOME=/usr/lib/jvm/java-17-openjdk-amd64 \
+   ANDROID_SDK_ROOT=$HOME/Development/android-sdk \
+   ANDROID_NDK_ROOT=$ANDROID_SDK_ROOT/ndk/23.1.7779620 \
+   ../kid3/build.sh)
 EOF
     chmod +x build-all.sh
   fi
@@ -355,7 +378,7 @@ fi
 if test "$1" = "flatpak"; then
   verify_not_in_srcdir
   echo "### Build flatpak"
-  flatpak-builder --sandbox --force-clean --ccache --repo=repo --subject="Build of org.kde.kid3 $(date --iso-8601=seconds)" app "$srcdir/packaging/flatpak/org.kde.kid3-local.json"
+  flatpak-builder --force-clean --ccache --repo=repo --subject="Build of org.kde.kid3 $(date --iso-8601=seconds)" app "$srcdir/packaging/flatpak/org.kde.kid3-local.json"
   exit 0
 fi
 
@@ -503,11 +526,15 @@ if test "$compiler" = "cross-android"; then
   _android_toolchain_cmake=$_android_ndk_root/build/cmake/android.toolchain.cmake
   test -f $_android_toolchain_cmake ||
     _android_toolchain_cmake=$srcdir/android/qt-android-cmake/toolchain/android.toolchain.cmake
-  test -f $_android_qt_root/bin/qmake ||
-    _android_qt_root=/opt/qt5/5.9.7/android_armv7
   if test -z "${_android_qt_root%%*x86}"; then
     _android_abi=x86
     _android_prefix=i686-linux-android
+  elif test -z "${_android_qt_root%%*x86_64}"; then
+    _android_abi=x86_64
+    _android_prefix=x86_64-linux-android
+  elif test -z "${_android_qt_root%%*arm64_v8a}"; then
+    _android_abi=arm64-v8a
+    _android_prefix=aarch64-linux-android
   else
     _android_abi=armeabi-v7a
     _android_prefix=arm-linux-androideabi
@@ -516,7 +543,7 @@ fi
 
 _chocoInstall=${ChocolateyInstall//\\/\/}
 _chocoInstall=${_chocoInstall/C:/\/c}
-for d in "$DOCBOOK_XSL_DIR" /usr/share/xml/docbook/stylesheet/nwalsh /usr/share/xml/docbook/xsl-stylesheets-* /usr/local/Cellar/docbook-xsl/*/docbook-xsl /opt/homebrew/Cellar/docbook-xsl/*/docbook-xsl /opt/local/share/xsl/docbook-xsl $_chocoInstall/lib/docbook-bundle/docbook-xsl-*; do
+for d in "$DOCBOOK_XSL_DIR" /usr/share/xml/docbook/stylesheet/nwalsh /usr/share/xml/docbook/xsl-stylesheets-* /usr/local/Cellar/docbook-xsl/*/docbook-xsl /opt/homebrew/Cellar/docbook-xsl/*/docbook-xsl $HOMEBREW_CELLAR/docbook-xsl/*/docbook-xsl /opt/local/share/xsl/docbook-xsl $_chocoInstall/lib/docbook-bundle/docbook-xsl-*; do
   if test -e $d/xhtml/docbook.xsl; then
     _docbook_xsl_dir=$d
     break
@@ -604,20 +631,30 @@ if test $kernel = "MINGW" || test "$compiler" = "cross-mingw"; then
 fi
 
 if test $kernel = "Darwin"; then
-  ARCH=$(uname -m)
-  #ARCH=i386
-  if test "$ARCH" = "i386"; then
+  MACHINE_ARCH=$(uname -m)
+  #MACHINE_ARCH=i386
+  if test "$MACHINE_ARCH" = "i386"; then
     # To build a 32-bit Mac OS X version of Kid3 use:
     # cmake -GNinja -DCMAKE_CXX_FLAGS="-arch i386" -DCMAKE_C_FLAGS="-arch i386" -DCMAKE_EXE_LINKER_FLAGS="-arch i386" -DQT_QMAKE_EXECUTABLE=/usr/local/Trolltech/Qt-${qt_version}-i386/bin/qmake -DCMAKE_BUILD_TYPE=Release -DWITH_FFMPEG=ON -DCMAKE_INSTALL_PREFIX= ../kid3
     # Building multiple architectures needs ARCH_FLAG="-arch i386 -arch x86_64",
     # CONFIGURE_OPTIONS="--disable-dependency-tracking", but it fails with libav.
+    ARCH=$MACHINE_ARCH
     ARCH_FLAG="-arch i386"
     export CC=gcc
     export CXX=g++
+  elif test "$MACHINE_ARCH" = "arm64"; then
+    # On Apple silicon, we can build for Intel or ARM. The environment variable
+    # ARCH=x86_64 or ARCH=arm64 can be passed to this script.
+    if test "$ARCH" != "x86_64"; then
+      ARCH=$MACHINE_ARCH
+    fi
+    _macosx_version_min=10.15
+    ARCH_FLAG="-arch $ARCH"
   else
+    ARCH=$MACHINE_ARCH
     ARCH_FLAG="-Xarch_x86_64"
   fi
-  if [[ $(sw_vers -productVersion) = 10.1* || $(sw_vers -productVersion) = 11.* ]]; then
+  if [[ $(sw_vers -productVersion) = 10.1* || $(sw_vers -productVersion) =~ ^1[1-9]\..*$ ]]; then
     CMAKE_OPTIONS="$CMAKE_OPTIONS -DCMAKE_C_FLAGS=\"-O2 $ARCH_FLAG -mmacosx-version-min=${_macosx_version_min}\" -DCMAKE_CXX_FLAGS=\"-O2 $ARCH_FLAG -mmacosx-version-min=${_macosx_version_min} -fvisibility=hidden -fvisibility-inlines-hidden -stdlib=libc++\" -DCMAKE_EXE_LINKER_FLAGS=\"$ARCH_FLAG -stdlib=libc++\" -DCMAKE_MODULE_LINKER_FLAGS=\"$ARCH_FLAG -stdlib=libc++\" -DCMAKE_SHARED_LINKER_FLAGS=\"$ARCH_FLAG -stdlib=libc++\""
     export CFLAGS="-O2 $ARCH_FLAG -mmacosx-version-min=${_macosx_version_min}"
     export CXXFLAGS="-O2 $ARCH_FLAG -mmacosx-version-min=${_macosx_version_min} -stdlib=libc++"
@@ -980,10 +1017,83 @@ download_openssl() {
   test -f Setenv-android.sh ||
     $DOWNLOAD https://wiki.openssl.org/images/7/70/Setenv-android.sh
   test -f openssl-${openssl_version}.tar.gz ||
-    $DOWNLOAD https://ftp.openssl.org/source/openssl-${openssl_version}.tar.gz
+    $DOWNLOAD https://www.openssl.org/source/openssl-${openssl_version}.tar.gz
   cd -
 }
 
+download_and_extract_qt() {
+  if ! test -d qt-${qt_version}; then
+    mkdir qt-${qt_version}
+    cd qt-${qt_version}
+    if test $qt_version = "6.5.3"; then
+      if test "$compiler" = "cross-android"; then
+        if test "$_android_abi" = "x86_64"; then
+          for m in qttranslations qttools qtsvg qtdeclarative qtbase; do
+            fn=6.5.3-0-202309260341${m}-Linux-RHEL_8_4-Clang-Android-Android_ANY-X86_64.7z
+            wget https://download.qt.io/online/qtsdkrepository/linux_x64/android/qt6_653_x86_64/qt.qt6.653.android_x86_64/$fn
+          done
+          for m in qtmultimedia qtimageformats; do
+            fn=qt.qt6.653.addons.${m}.android_x86_64/6.5.3-0-202309260341${m}-Linux-RHEL_8_4-Clang-Android-Android_ANY-X86_64.7z
+            wget https://download.qt.io/online/qtsdkrepository/linux_x64/android/qt6_653_x86_64/$fn
+          done
+        elif test "$_android_abi" = "arm64-v8a"; then
+          for m in qttranslations qttools qtsvg qtdeclarative qtbase; do
+            fn=6.5.3-0-202309260341${m}-MacOS-MacOS_12-Clang-Android-Android_ANY-ARM64.7z
+            wget https://download.qt.io/online/qtsdkrepository/linux_x64/android/qt6_653_arm64_v8a/qt.qt6.653.android_arm64_v8a/$fn
+          done
+          for m in qtmultimedia qtimageformats; do
+            fn=qt.qt6.653.addons.${m}.android_arm64_v8a/6.5.3-0-202309260341${m}-MacOS-MacOS_12-Clang-Android-Android_ANY-ARM64.7z
+            wget https://download.qt.io/online/qtsdkrepository/linux_x64/android/qt6_653_arm64_v8a/$fn
+          done
+        else
+          for m in qttranslations qttools qtsvg qtdeclarative qtbase; do
+            fn=6.5.3-0-202309260341${m}-Windows-Windows_10_22H2-Clang-Android-Android_ANY-ARMv7.7z
+            $DOWNLOAD https://download.qt.io/online/qtsdkrepository/linux_x64/android/qt6_653_armv7/qt.qt6.653.android_armv7/$fn
+          done
+          for m in qtmultimedia qtimageformats; do
+            fn=qt.qt6.653.addons.${m}.android_armv7/6.5.3-0-202309260341${m}-Windows-Windows_10_22H2-Clang-Android-Android_ANY-ARMv7.7z
+            $DOWNLOAD https://download.qt.io/online/qtsdkrepository/linux_x64/android/qt6_653_armv7/$fn
+          done
+        fi
+      elif test $kernel = "Linux"; then
+        for m in qttranslations qttools qtsvg qtdeclarative qtbase qtwayland; do
+          fn=6.5.3-0-202309260341${m}-Linux-RHEL_8_4-GCC-Linux-RHEL_8_4-X86_64.7z
+          $DOWNLOAD https://download.qt.io/online/qtsdkrepository/linux_x64/desktop/qt6_653/qt.qt6.653.gcc_64/$fn
+        done
+        $DOWNLOAD https://download.qt.io/online/qtsdkrepository/linux_x64/desktop/qt6_653/qt.qt6.653.gcc_64/6.5.3-0-202309260341icu-linux-Rhel7.2-x64.7z
+        for m in qtmultimedia qtimageformats; do
+          fn=qt.qt6.653.addons.${m}.gcc_64/6.5.3-0-202309260341${m}-Linux-RHEL_8_4-GCC-Linux-RHEL_8_4-X86_64.7z
+          $DOWNLOAD https://download.qt.io/online/qtsdkrepository/linux_x64/desktop/qt6_653/$fn
+        done
+      elif test $kernel = "Darwin"; then
+        for m in qttranslations qttools qtsvg qtdeclarative qtbase; do
+          fn=6.5.3-0-202309260341${m}-MacOS-MacOS_12-Clang-MacOS-MacOS_12-X86_64-ARM64.7z
+          $DOWNLOAD https://download.qt.io/online/qtsdkrepository/mac_x64/desktop/qt6_653/qt.qt6.653.clang_64/$fn
+        done
+        for m in qtmultimedia qtimageformats; do
+          fn=qt.qt6.653.addons.${m}.clang_64/6.5.3-0-202309260341${m}-MacOS-MacOS_12-Clang-MacOS-MacOS_12-X86_64-ARM64.7z
+          $DOWNLOAD https://download.qt.io/online/qtsdkrepository/mac_x64/desktop/qt6_653/$fn
+        done
+      elif test $kernel = "MINGW"; then
+        for m in qttranslations qttools qtsvg qtdeclarative qtbase; do
+          fn=6.5.3-0-202309260341${m}-Windows-Windows_10_22H2-Mingw-Windows-Windows_10_22H2-X86_64.7z
+          $DOWNLOAD https://download.qt.io/online/qtsdkrepository/windows_x86/desktop/qt6_653/qt.qt6.653.win64_mingw/$fn
+        done
+        for m in opengl32sw-64-mesa_11_2_2-signed_sha256 d3dcompiler_47-x64 MinGW-w64-x86_64-11.2.0-release-posix-seh-rt_v9-rev1-runtime; do
+          fn=6.5.3-0-202309260341${m}.7z
+          $DOWNLOAD https://download.qt.io/online/qtsdkrepository/windows_x86/desktop/qt6_653/qt.qt6.653.win64_mingw/$fn
+        done
+        for m in qtmultimedia qtimageformats; do
+          fn=qt.qt6.653.addons.${m}.win64_mingw/6.5.3-0-202309260341${m}-Windows-Windows_10_22H2-Mingw-Windows-Windows_10_22H2-X86_64.7z
+          $DOWNLOAD https://download.qt.io/online/qtsdkrepository/windows_x86/desktop/qt6_653/$fn
+        done
+      fi
+      for fn in *.7z; do 7za x $fn; done
+      rm -f *.7z
+    fi
+    cd -
+  fi
+}
 
 # Extract and patch sources
 
@@ -1026,7 +1136,9 @@ extract_zlib() {
 
       tar xJf $SRC_ARCHIVE_DIR/zlib_${zlib_version}.dfsg-${zlib_patchlevel}.debian.tar.xz || true
       echo Can be ignored: Cannot create symlink to debian.series
-      for f in $(cat debian/patches/debian.series); do patch -p1 <debian/patches/$f; done
+      if test -f debian/patches/debian.series; then
+        for f in $(cat debian/patches/debian.series); do patch -p1 <debian/patches/$f; done
+      fi
       cd ..
     fi
   fi
@@ -1053,7 +1165,9 @@ extract_libvorbis() {
     tar xzf $SRC_ARCHIVE_DIR/libvorbis_${libvorbis_version}.orig.tar.gz
     cd libvorbis-${libvorbis_version}/
     tar xJf $SRC_ARCHIVE_DIR/libvorbis_${libvorbis_version}-${libvorbis_patchlevel}.debian.tar.xz
-    for f in $(cat debian/patches/series); do patch -p1 <debian/patches/$f; done
+    if test -f debian/patches/series; then
+      for f in $(cat debian/patches/series); do patch -p1 <debian/patches/$f; done
+    fi
     test -f win32/VS2010/libogg.props.orig || mv win32/VS2010/libogg.props win32/VS2010/libogg.props.orig
     sed "s/<LIBOGG_VERSION>1.2.0</<LIBOGG_VERSION>$libogg_version</" win32/VS2010/libogg.props.orig >win32/VS2010/libogg.props
     cd ..
@@ -1067,7 +1181,9 @@ extract_libflac() {
     tar xJf $SRC_ARCHIVE_DIR/flac_${libflac_version}.orig.tar.xz
     cd flac-${libflac_version%+ds*}/
     tar xJf $SRC_ARCHIVE_DIR/flac_${libflac_version}-${libflac_patchlevel}.debian.tar.xz
-    for f in $(cat debian/patches/series); do patch -p1 <debian/patches/$f; done
+    if test -f debian/patches/series; then
+      for f in $(cat debian/patches/series); do patch -p1 <debian/patches/$f; done
+    fi
     patch -p1 <$srcdir/packaging/patches/flac-1.2.1-00-size_t_max.patch
     cd ..
   fi
@@ -1080,7 +1196,9 @@ extract_id3lib() {
     tar xzf $SRC_ARCHIVE_DIR/id3lib3.8.3_${id3lib_version}.orig.tar.gz
     cd id3lib-${id3lib_version}/
     tar xJf $SRC_ARCHIVE_DIR/id3lib3.8.3_${id3lib_version}-${id3lib_patchlevel}.debian.tar.xz
-    for f in $(cat debian/patches/series); do patch --binary -p1 <debian/patches/$f; done
+    if test -f debian/patches/series; then
+      for f in $(cat debian/patches/series); do patch --binary -p1 <debian/patches/$f; done
+    fi
     patch -p1 <$srcdir/packaging/patches/id3lib-3.8.3-win00-mingw.patch
     patch -p1 <$srcdir/packaging/patches/id3lib-3.8.3-win01-tempfile.patch
     test -f makefile.win32.orig || mv makefile.win32 makefile.win32.orig
@@ -1096,7 +1214,9 @@ extract_ffmpeg() {
     tar xJf $SRC_ARCHIVE_DIR/ffmpeg_${ffmpeg_version}.orig.tar.xz || true
     cd ffmpeg-${ffmpeg_version}/
     tar xJf $SRC_ARCHIVE_DIR/ffmpeg_${ffmpeg_version}-${ffmpeg_patchlevel}.debian.tar.xz || true
-    for f in $(cat debian/patches/series); do patch -p1 <debian/patches/$f; done
+    if test -f debian/patches/series; then
+      for f in $(cat debian/patches/series); do patch -p1 <debian/patches/$f; done
+    fi
     cd ..
   fi
 }
@@ -1108,7 +1228,9 @@ extract_chromaprint() {
     tar xzf $SRC_ARCHIVE_DIR/chromaprint_${chromaprint_version}.orig.tar.gz
     cd chromaprint-${chromaprint_version}/
     tar xJf $SRC_ARCHIVE_DIR/chromaprint_${chromaprint_version}-${chromaprint_patchlevel}.debian.tar.xz
-    for f in $(cat debian/patches/series); do patch -p1 <debian/patches/$f; done
+    if test -f debian/patches/series; then
+      for f in $(cat debian/patches/series); do patch -p1 <debian/patches/$f; done
+    fi
     cd ..
   fi
 }
@@ -1155,6 +1277,10 @@ if test "$compiler" = "cross-android"; then
     if test "$qt_nr" -lt 60000; then
       if test "$_android_abi" = "x86"; then
         sed -i 's/^_ANDROID_EABI=.*$/_ANDROID_EABI=x86-4.9/; s/^_ANDROID_ARCH=.*$/_ANDROID_ARCH=arch-x86/' Setenv-android.sh
+      elif test "$_android_abi" = "x86_64"; then
+        sed -i 's/^_ANDROID_EABI=.*$/_ANDROID_EABI=x86_64-4.9/; s/^_ANDROID_ARCH=.*$/_ANDROID_ARCH=arch-x86_64/' Setenv-android.sh
+      elif test "$_android_abi" = "arm64-v8a"; then
+        sed -i 's/^_ANDROID_EABI=.*$/_ANDROID_EABI=aarch64-linux-android-4.9/; s/^_ANDROID_ARCH=.*$/_ANDROID_ARCH=arch-arm64/' Setenv-android.sh
       else
         sed -i 's/^_ANDROID_EABI=.*$/_ANDROID_EABI=arm-linux-androideabi-4.9/; s/^_ANDROID_ARCH=.*$/_ANDROID_ARCH=arch-arm/' Setenv-android.sh
       fi
@@ -1172,6 +1298,10 @@ if test "$compiler" = "cross-android"; then
       if test -d $_android_ndk_root/toolchains/llvm; then
         if test "$_android_abi" = "x86"; then
           sed -i 's/^CC=.*$/CC= i686-linux-android16-clang/; s/ -mandroid//' Makefile
+        elif test "$_android_abi" = "x86_64"; then
+          sed -i 's/^CC=.*$/CC= x86_64-linux-android16-clang/; s/ -mandroid//' Makefile
+        elif test "$_android_abi" = "arm64-v8a"; then
+          sed -i 's/^CC=.*$/CC= aarch64-linux-android-clang/; s/ -mandroid//' Makefile
         else
           sed -i 's/^CC=.*$/CC= armv7a-linux-androideabi16-clang/; s/ -mandroid//' Makefile
         fi
@@ -1187,7 +1317,16 @@ if test "$compiler" = "cross-android"; then
     else
       PATH=$ANDROID_NDK_ROOT/toolchains/llvm/prebuilt/linux-x86_64/bin:$PATH
       sed -i 's/shared_extension => ".so",/shared_extension => "_3.so",/' Configurations/15-android.conf
-      ANDROID_NDK_HOME=$ANDROID_NDK_ROOT ./Configure shared android-arm
+      if test "$_android_abi" = "x86"; then
+        _os_compiler=android-x86
+      elif test "$_android_abi" = "x86_64"; then
+        _os_compiler=android-x86_64
+      elif test "$_android_abi" = "arm64-v8a"; then
+        _os_compiler=android-arm64
+      else
+        _os_compiler=android-arm
+      fi
+      ANDROID_NDK_HOME=$ANDROID_NDK_ROOT ./Configure shared $_os_compiler
       sed -i "s,^DESTDIR=\$,DESTDIR=$PWD/inst," Makefile
       make -j ANDROID_NDK_HOME=$ANDROID_NDK_ROOT SHLIB_VERSION_NUMBER= SHLIB_EXT=_3.so build_libs install_dev
       _ssl_lib_suffix=_3.so
@@ -1234,6 +1373,13 @@ if test "$compiler" = "cross-android"; then
   fi
   extract_binary_archive $BIN_ARCHIVE_DIR/taglib-${taglib_version}.tgz
 
+  # Set a QTPREFIX starting with "$(pwd)/qt-", e.g. $(pwd)/qt-6.5.3/6.5.3/android_arm64_v8a
+  # or $(pwd)/qt-6.5.3/6.5.3/android_armv7 or $(pwd)/qt-6.5.3/6.5.3/android_x86_64
+  # in order to download Qt binaries to the given $QTPREFIX if it does not already exist.
+  if test "${QTPREFIX%%/qt-*}" = "$(pwd)" -a ! -d "$QTPREFIX"; then
+    download_and_extract_qt
+  fi
+
 else #  cross-android
 
   if ( test "$compiler" = "gcc-self-contained" || test "$compiler" = "gcc-debug" ) \
@@ -1360,7 +1506,7 @@ else #  cross-android
   fi
   extract_binary_archive $BIN_ARCHIVE_DIR/flac-${libflac_version}.tgz
 
-  if test ! -f $BIN_ARCHIVE_DIR/id3lib-${id3lib_version}.tgz && ! test $kernel = "Darwin" -a $ARCH = "arm64"; then
+  if test ! -f $BIN_ARCHIVE_DIR/id3lib-${id3lib_version}.tgz && ! test $kernel = "Darwin" -a $(uname -m) = "arm64"; then
     download_id3lib
     extract_id3lib
     echo "### Building id3lib"
@@ -1463,6 +1609,9 @@ else #  cross-android
     if test $kernel = "Darwin" || test $kernel = "MINGW"; then
       AV_CONFIGURE_OPTIONS="$AV_CONFIGURE_OPTIONS --disable-iconv"
     fi
+    if test $kernel = "Darwin" && test $(uname -m) = "arm64"; then
+      AV_CONFIGURE_OPTIONS="$AV_CONFIGURE_OPTIONS --arch=$ARCH"
+    fi
     AV_CONFIGURE_OPTIONS="$AV_CONFIGURE_OPTIONS $AV_BUILD_OPTION"
     ./configure \
       --disable-shared \
@@ -1583,6 +1732,12 @@ else #  cross-android
   fi
   extract_binary_archive $BIN_ARCHIVE_DIR/mp4v2-${mp4v2_version}.tgz
 
+  # Set a QTPREFIX starting with "$(pwd)/qt-", e.g. $(pwd)/qt-6.5.3/6.5.3/gcc_64
+  # for Linux or $(pwd)/qt-6.5.3/6.5.3/macos for macOS in order to download Qt
+  # binaries to the given $QTPREFIX if it does not already exist.
+  if test "${QTPREFIX%%/qt-*}" = "$(pwd)" -a ! -d "$QTPREFIX"; then
+    download_and_extract_qt
+  fi
 fi # cross-android, else
 fi # libs
 
@@ -1630,7 +1785,7 @@ EOF
         cat >kid3/run-cmake.sh <<EOF
 #!/bin/bash
 test -z \${PATH##$osxprefix/*} || PATH=$osxprefix/bin:$osxsdk/usr/bin:\$PATH
-cmake -GNinja $CMAKE_BUILD_OPTION -DCMAKE_TOOLCHAIN_FILE=$thisdir/osxcross.cmake -DCMAKE_INSTALL_PREFIX= -DCMAKE_CXX_FLAGS="-g -O2 -DMP4V2_USE_STATIC_LIB" -DWITH_FFMPEG=ON -DWITH_MP4V2=ON -DDOCBOOK_XSL_DIR=${_docbook_xsl_dir} ../../kid3
+cmake -GNinja $CMAKE_BUILD_OPTION -DREMOVE_ARCH=arm64 -DCMAKE_TOOLCHAIN_FILE=$thisdir/osxcross.cmake -DCMAKE_INSTALL_PREFIX= -DCMAKE_CXX_FLAGS="-g -O2 -DMP4V2_USE_STATIC_LIB" -DWITH_FFMPEG=ON -DWITH_MP4V2=ON -DDOCBOOK_XSL_DIR=${_docbook_xsl_dir} ../../kid3
 EOF
       elif test "$compiler" = "gcc-self-contained"; then
         if test -n "$QTPREFIX"; then
@@ -1647,13 +1802,18 @@ EOF
 #!/bin/bash
 BUILDPREFIX=\$(cd ..; pwd)/buildroot/usr/local
 export PKG_CONFIG_PATH=\$BUILDPREFIX/lib/pkgconfig
-cmake -GNinja $CMAKE_BUILD_OPTION -DCMAKE_CXX_COMPILER=${gcc_self_contained_cxx} -DCMAKE_C_COMPILER=${gcc_self_contained_cc} -DQT_QMAKE_EXECUTABLE=${_qt_prefix}/bin/qmake -DWITH_READLINE=OFF -DLINUX_SELF_CONTAINED=ON -DWITH_QML=ON -DCMAKE_PREFIX_PATH=\$BUILDPREFIX -DWITH_FFMPEG=ON -DFFMPEG_ROOT=\$BUILDPREFIX -DWITH_MP4V2=ON -DWITH_APPS="Qt;CLI" -DCMAKE_INSTALL_PREFIX= -DWITH_BINDIR=. -DWITH_DATAROOTDIR=. -DWITH_DOCDIR=. -DWITH_TRANSLATIONSDIR=. -DWITH_LIBDIR=. -DWITH_PLUGINSDIR=./plugins ../../kid3
+cmake -GNinja $CMAKE_BUILD_OPTION -DCMAKE_CXX_COMPILER=${gcc_self_contained_cxx} -DCMAKE_C_COMPILER=${gcc_self_contained_cc} -DQT_QMAKE_EXECUTABLE=${_qt_prefix}/bin/qmake -DWITH_READLINE=OFF -DLINUX_SELF_CONTAINED=ON -DWITH_QML=ON -DCMAKE_PREFIX_PATH=\$BUILDPREFIX -DWITH_FFMPEG=ON -DFFMPEG_ROOT=\$BUILDPREFIX -DWITH_MP4V2=ON -DWITH_APPS="Qt;CLI" -DCMAKE_INSTALL_PREFIX= -DWITH_BINDIR=. -DWITH_DATAROOTDIR=. -DWITH_DOCDIR=. -DWITH_TRANSLATIONSDIR=. -DWITH_LIBDIR=. -DWITH_PLUGINSDIR=./plugins -DWITH_DOCBOOKDIR=${_docbook_xsl_dir} ../../kid3
 EOF
-      elif test $kernel = "Darwin" -a "$ARCH" = "arm64"; then
+      elif test $kernel = "Darwin" -a "$(uname -m)" = "arm64"; then
+        if test "$ARCH" = "arm64"; then
+          _other_arch=x86_64
+        else
+          _other_arch=arm64
+        fi
         _qt_prefix=${QTPREFIX:-/usr/local/Trolltech/Qt${qt_version}/${qt_version}/clang_64}
         cat >kid3/run-cmake.sh <<EOF
 #!/bin/bash
-INCLUDE=../buildroot/usr/local/include LIB=../buildroot/usr/local/lib cmake -GNinja -DCMAKE_BUILD_TYPE=RelWithDebInfo -DQT_QMAKE_EXECUTABLE=${_qt_prefix}/bin/qmake -DCMAKE_INSTALL_PREFIX= -DCMAKE_PREFIX_PATH=$thisdir/buildroot/usr/local -DWITH_FFMPEG=ON -DWITH_MP4V2=ON -DWITH_ID3LIB=OFF -DWITH_DOCBOOKDIR=${_docbook_xsl_dir} ../../kid3
+INCLUDE=../buildroot/usr/local/include LIB=../buildroot/usr/local/lib cmake $CMAKE_BUILD_OPTION $CMAKE_OPTIONS -DCMAKE_APPLE_SILICON_PROCESSOR=$ARCH -DREMOVE_ARCH=$_other_arch -DQT_QMAKE_EXECUTABLE=${_qt_prefix}/bin/qmake -DCMAKE_INSTALL_PREFIX= -DCMAKE_PREFIX_PATH=$thisdir/buildroot/usr/local -DWITH_FFMPEG=ON -DWITH_MP4V2=ON -DWITH_ID3LIB=OFF -DWITH_DOCBOOKDIR=${_docbook_xsl_dir} ../../kid3
 EOF
       elif test $kernel = "Darwin"; then
         _qt_prefix=${QTPREFIX:-/usr/local/Trolltech/Qt${qt_version}/${qt_version}/clang_64}
@@ -1700,14 +1860,14 @@ EOF
 #!/bin/bash
 BUILDPREFIX=\$(cd ..; pwd)/buildroot/usr/local
 export PKG_CONFIG_PATH=\$BUILDPREFIX/lib/pkgconfig
-cmake -GNinja -DQT_QMAKE_EXECUTABLE=${QTPREFIX:-$QT_PREFIX}/bin/qmake -DLINUX_SELF_CONTAINED=ON -DWITH_READLINE=OFF -DWITH_QML=ON -DCMAKE_CXX_FLAGS_DEBUG:STRING="-g -DMP4V2_USE_STATIC_LIB -DID3LIB_LINKOPTION=1 -DFLAC__NO_DLL -DTAGLIB_STATIC" -DCMAKE_PREFIX_PATH=\$BUILDPREFIX -DWITH_FFMPEG=ON -DFFMPEG_ROOT=\$BUILDPREFIX -DWITH_MP4V2=ON $CMAKE_BUILD_OPTION -DWITH_APPS="Qt;CLI" -DCMAKE_INSTALL_PREFIX= -DWITH_BINDIR=. -DWITH_DATAROOTDIR=. -DWITH_DOCDIR=. -DWITH_TRANSLATIONSDIR=. -DWITH_LIBDIR=. -DWITH_PLUGINSDIR=./plugins ../../kid3
+cmake -GNinja -DQT_QMAKE_EXECUTABLE=${QTPREFIX:-$QT_PREFIX}/bin/qmake -DLINUX_SELF_CONTAINED=ON -DWITH_READLINE=OFF -DWITH_QML=ON -DCMAKE_CXX_FLAGS_DEBUG:STRING="-g -DMP4V2_USE_STATIC_LIB -DID3LIB_LINKOPTION=1 -DFLAC__NO_DLL -DTAGLIB_STATIC" -DCMAKE_PREFIX_PATH=\$BUILDPREFIX -DWITH_FFMPEG=ON -DFFMPEG_ROOT=\$BUILDPREFIX -DWITH_MP4V2=ON $CMAKE_BUILD_OPTION -DWITH_APPS="Qt;CLI" -DCMAKE_INSTALL_PREFIX= -DWITH_BINDIR=. -DWITH_DATAROOTDIR=. -DWITH_DOCDIR=. -DWITH_TRANSLATIONSDIR=. -DWITH_LIBDIR=. -DWITH_PLUGINSDIR=./plugins -DWITH_DOCBOOKDIR=${_docbook_xsl_dir} ../../kid3
 EOF
       else
         cat >kid3/run-cmake.sh <<EOF
 #!/bin/bash
 BUILDPREFIX=\$(cd ..; pwd)/buildroot/usr/local
 export PKG_CONFIG_PATH=\$BUILDPREFIX/lib/pkgconfig
-cmake -GNinja -DLINUX_SELF_CONTAINED=ON -DWITH_QML=ON -DCMAKE_CXX_FLAGS_DEBUG:STRING="-g -DMP4V2_USE_STATIC_LIB -DID3LIB_LINKOPTION=1 -DFLAC__NO_DLL -DTAGLIB_STATIC" -DCMAKE_PREFIX_PATH=\$BUILDPREFIX -DWITH_FFMPEG=ON -DFFMPEG_ROOT=\$BUILDPREFIX -DWITH_MP4V2=ON $CMAKE_BUILD_OPTION -DWITH_APPS="Qt;CLI" -DCMAKE_INSTALL_PREFIX= -DWITH_BINDIR=. -DWITH_DATAROOTDIR=. -DWITH_DOCDIR=. -DWITH_TRANSLATIONSDIR=. -DWITH_LIBDIR=. -DWITH_PLUGINSDIR=./plugins ../../kid3
+cmake -GNinja -DLINUX_SELF_CONTAINED=ON -DWITH_QML=ON -DCMAKE_CXX_FLAGS_DEBUG:STRING="-g -DMP4V2_USE_STATIC_LIB -DID3LIB_LINKOPTION=1 -DFLAC__NO_DLL -DTAGLIB_STATIC" -DCMAKE_PREFIX_PATH=\$BUILDPREFIX -DWITH_FFMPEG=ON -DFFMPEG_ROOT=\$BUILDPREFIX -DWITH_MP4V2=ON $CMAKE_BUILD_OPTION -DWITH_APPS="Qt;CLI" -DCMAKE_INSTALL_PREFIX= -DWITH_BINDIR=. -DWITH_DATAROOTDIR=. -DWITH_DOCDIR=. -DWITH_TRANSLATIONSDIR=. -DWITH_LIBDIR=. -DWITH_PLUGINSDIR=./plugins -DWITH_DOCBOOKDIR=${_docbook_xsl_dir} ../../kid3
 EOF
       fi
       chmod +x kid3/run-cmake.sh
@@ -1789,7 +1949,7 @@ EOF
       for suffix in signed unsigned; do
         _apkpath=${prefix}-${suffix}.apk
         if test -f $_apkpath; then
-          cp -a $_apkpath kid3-$_version-android.apk
+          cp -a $_apkpath kid3-$_version-android-$_android_abi.apk
           break 2
         fi
       done
@@ -1810,4 +1970,6 @@ EOF
   popd >/dev/null
 fi # package
 
+trap - ERR
+
 echo "### Built successfully"
