@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 17 Sep 2003
  *
- * Copyright (C) 2003-2012  Urs Fleisch
+ * Copyright (C) 2003-2024  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -24,8 +24,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef CONFIGDIALOG_H
-#define CONFIGDIALOG_H
+#pragma once
 
 #include <QDialog>
 
@@ -55,12 +54,12 @@ public:
    * @param shortcutsModel shortcuts model
    */
   ConfigDialog(IPlatformTools* platformTools, QWidget* parent,
-               QString& caption, ShortcutsModel* shortcutsModel);
+               const QString& caption, ShortcutsModel* shortcutsModel);
 
   /**
    * Destructor.
    */
-  virtual ~ConfigDialog();
+  ~ConfigDialog() override = default;
 
   /**
    * Set values in dialog from current configuration.
@@ -126,11 +125,10 @@ private:
   QPushButton* m_applicationFontButton;
   QCheckBox* m_useApplicationStyleCheckBox;
   QComboBox* m_applicationStyleComboBox;
+  QComboBox* m_languageComboBox;
   QCheckBox* m_useNativeDialogsCheckBox;
   QFont m_font;
   QString m_style;
   bool m_fontChanged;
   bool m_styleChanged;
 };
-
-#endif
