@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 29 Jun 2013
  *
- * Copyright (C) 2013-2018  Urs Fleisch
+ * Copyright (C) 2013-2024  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -34,7 +34,7 @@ int GuiConfig::s_index = -1;
  * Constructor.
  */
 GuiConfig::GuiConfig()
-  : StoredConfig<GuiConfig>(QLatin1String("GUI")),
+  : StoredConfig(QLatin1String("GUI")),
     m_fileListSortColumn(0),
     m_fileListSortOrder(Qt::AscendingOrder),
     m_dirListSortColumn(0),
@@ -75,6 +75,8 @@ void GuiConfig::writeToConfig(ISettings* config) const
                    QVariant(m_selectFileOnPlayEnabled));
   config->setValue(QLatin1String("PlayToolBarVisible"),
                    QVariant(m_playToolBarVisible));
+  config->setValue(QLatin1String("PreferredAudioOutput"),
+                   QVariant(m_preferredAudioOutput));
   config->setValue(QLatin1String("FileListVisibleColumns"),
                    QVariant(intListToStringList(m_fileListVisibleColumns)));
   config->setValue(QLatin1String("FileListCustomColumnWidthsEnabled"),
@@ -143,6 +145,8 @@ void GuiConfig::readFromConfig(ISettings* config)
                     m_selectFileOnPlayEnabled).toBool();
   m_playToolBarVisible = config->value(QLatin1String("PlayToolBarVisible"),
                                        m_playToolBarVisible).toBool();
+  m_preferredAudioOutput = config->value(QLatin1String("PreferredAudioOutput"),
+                                         m_preferredAudioOutput).toString();
   m_fileListVisibleColumns = stringListToIntList(
         config->value(QLatin1String("FileListVisibleColumns"), QStringList())
         .toStringList());
@@ -184,9 +188,9 @@ void GuiConfig::readFromConfig(ISettings* config)
         .toStringList());
   m_splitterSizes.clear();
   for (int i = 0; i < 5; ++i) {
-    int val = config->value(QLatin1String("SplitterSize") + QString::number(i),
-                            -1).toInt();
-    if (val != -1) {
+    if (int val = config->value(
+          QLatin1String("SplitterSize") + QString::number(i),-1).toInt();
+        val != -1) {
       m_splitterSizes.push_back(val);
     } else {
       break;
@@ -194,9 +198,9 @@ void GuiConfig::readFromConfig(ISettings* config)
   }
   m_vSplitterSizes.clear();
   for (int j = 0; j < 5; ++j) {
-    int val = config->value(QLatin1String("VSplitterSize") + QString::number(j),
-                            -1).toInt();
-    if (val != -1) {
+    if (int val = config->value(
+          QLatin1String("VSplitterSize") + QString::number(j), -1).toInt();
+        val != -1) {
       m_vSplitterSizes.push_back(val);
     } else {
       break;
@@ -363,6 +367,14 @@ void GuiConfig::setPlayToolBarVisible(bool playToolBarVisible)
   }
 }
 
+void GuiConfig::setPreferredAudioOutput(const QString& preferredAudioOutput)
+{
+  if (m_preferredAudioOutput != preferredAudioOutput) {
+    m_preferredAudioOutput = preferredAudioOutput;
+    emit preferredAudioOutputChanged(m_preferredAudioOutput);
+  }
+}
+
 void GuiConfig::setPlayToolBarArea(int playToolBarArea)
 {
   if (m_playToolBarArea != playToolBarArea) {
