@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 12 Jun 2011
  *
- * Copyright (C) 2011-2018  Urs Fleisch
+ * Copyright (C) 2011-2024  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -46,7 +46,7 @@ public:
   /**
    * Destructor.
    */
-  virtual ~DownloadClient() override = default;
+  ~DownloadClient() override = default;
 
   /**
    * Send a download request.
