@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 25 Aug 2007
  *
- * Copyright (C) 2007-2018  Urs Fleisch
+ * Copyright (C) 2007-2024  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -765,6 +765,23 @@ public:
    */
   static QLatin1Char stringListSeparator() { return QLatin1Char('|'); }
 
+  /**
+   * Split a string into a string list using stringListSeparator().
+   * @param str string to split at stringListSeparator(), with support of
+   *            '\' as an escape character.
+   * @return list of strings split at separator character not prefixed with
+   *         escape character.
+   */
+  static QStringList splitStringList(const QString& str);
+
+  /**
+   * Join a string list using stringListSeparator().
+   * @param strs strings to join, if they contain the separator character,
+   *             it will be escaped with '\'.
+   * @return escaped strings joined by separator characters.
+   */
+  static QString joinStringList(const QStringList& strs);
+
   /**
    * Convert string (e.g. "track/total number of tracks") to number.
    *
@@ -1318,7 +1335,7 @@ public:
   /**
    * Destructor.
    */
-  virtual ~FrameFormatReplacer() override = default;
+  ~FrameFormatReplacer() override = default;
 
   FrameFormatReplacer(const FrameFormatReplacer& other) = delete;
   FrameFormatReplacer &operator=(const FrameFormatReplacer& other) = delete;
@@ -1351,7 +1368,7 @@ protected:
    * @return replacement string,
    *         QString::null if code not found.
    */
-  virtual QString getReplacement(const QString& code) const override;
+  QString getReplacement(const QString& code) const override;
 
 private:
   const FrameCollection& m_frames;
