@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 10 Jun 2009
  *
- * Copyright (C) 2003-2018  Urs Fleisch
+ * Copyright (C) 2003-2024  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -46,7 +46,7 @@ public:
   /**
    * Destructor.
    */
-  virtual ~ImageViewer() override {}
+  ~ImageViewer() override {}
 
 private:
   /** image to view */
