@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 15 Feb 2013
  *
- * Copyright (C) 2013  Urs Fleisch
+ * Copyright (C) 2013-2024  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -24,8 +24,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef FFMPEGFINGERPRINTDECODER_H
-#define FFMPEGFINGERPRINTDECODER_H
+#pragma once
 
 #include "abstractfingerprintdecoder.h"
 
@@ -38,22 +37,20 @@ public:
    * Constructor.
    * @param parent parent object
    */
-  explicit FFmpegFingerprintDecoder(QObject* parent = 0);
+  explicit FFmpegFingerprintDecoder(QObject* parent = nullptr);
 
   /**
    * Destructor.
    */
-  virtual ~FFmpegFingerprintDecoder();
+  ~FFmpegFingerprintDecoder() override;
 
   /**
    * Run decoder on audio file.
    * @param filePath path to audio file
    */
-  virtual void start(const QString& filePath);
+  void start(const QString& filePath) override;
 
 private:
   qint16* m_buffer1;
   qint16* m_buffer2;
 };
-
-#endif // FFMPEGFINGERPRINTDECODER_H
