@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 09 Oct 2012
  *
- * Copyright (C) 2012  Urs Fleisch
+ * Copyright (C) 2012-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -24,8 +24,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef TESTDISCOGSIMPORTER_H
-#define TESTDISCOGSIMPORTER_H
+#pragma once
 
 #include "testserverimporterbase.h"
 
@@ -36,5 +35,3 @@ private slots:
   void testQueryAlbums();
   void testQueryTracks();
 };
-
-#endif
